@@ -12,7 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
+
 import testtools
 
 from scciclient.irmc import scci
@@ -51,6 +52,7 @@ class VIOMConfigurationTestCase(testtools.TestCase):
             },
             'InitBoot': reboot,
             'Mode': 'delete',
+            '@Version': '1.00',
         }
         mock_set.assert_called_once_with(expected_json)
 
@@ -75,7 +77,8 @@ class VIOMConfigurationTestCase(testtools.TestCase):
             },
             'Slots': {
                 'Slot': [slot_json]
-            }
+            },
+            '@Version': '1.00',
         }
 
     @staticmethod
@@ -86,7 +89,8 @@ class VIOMConfigurationTestCase(testtools.TestCase):
             },
             'Slots': {
                 'Slot': [slot_json]
-            }
+            },
+            '@Version': '1.00',
         }
 
     @staticmethod
